@@ -368,7 +368,11 @@ void dwm_init_mararc() {
         dwm_dict_init();
         /* Numeric mararc variables have default values.  */
         key_n[DWM_N_maxprocs] = 32;
+#ifndef FALLBACK_TIME
+        key_n[DWM_N_timeout_seconds] = 1;
+#else /* FALLBACK_TIME */
         key_n[DWM_N_timeout_seconds] = 2;
+#endif /* FALLBACK_TIME */
         key_n[DWM_N_dns_port] = 53;
         key_n[DWM_N_upstream_port] = 53;
         key_n[DWM_N_handle_overload] = 1;
@@ -380,7 +384,7 @@ void dwm_init_mararc() {
         key_n[DWM_N_maradns_uid] = 99;
         key_n[DWM_N_maradns_gid] = 99;
         key_n[DWM_N_resurrections] = 1;
-        key_n[DWM_N_num_retries] = 2;
+        key_n[DWM_N_num_retries] = 5;
         key_n[DWM_N_verbose_level] = 3;
         key_n[DWM_N_max_tcp_procs] = 8;
         key_n[DWM_N_timeout_seconds_tcp] = 4;
@@ -395,6 +399,7 @@ void dwm_init_mararc() {
         key_n[DWM_N_reject_mx] = 1;
         key_n[DWM_N_truncation_hack] = 1;
         key_n[DWM_N_reject_ptr] = 0;
+        key_n[DWM_N_min_ttl_incomplete_cname] = 3600;
 }
 
 /* Look for a Mararc parameter; -1 if not found/error; 0-n if found
@@ -569,13 +574,16 @@ void dwm_dict_add(int num, dw_str *key, dw_str *value, int todo) {
         if(key_d[num] == 0 && todo == 6) { /* Initialized with {} */
                 key_d[num] = dwd_init();
                 return;
+#ifndef TINY_BINARY
         } else if(key_d[num] != 0 && todo == 6) { /* Only initialize once */
                 dwm_fatal("Dictionary variable already initialized");
+#endif /* TINY_BINARY */
         } else if(key_d[num] == 0) {
                 dwm_fatal("Uninitialized dictionary variable");
         }
 
         if(todo != 4) { /* =, create new dictionary element */
+#ifndef TINY_BINARY
                 check = dwd_fetch(key_d[num],key);
                 if(check != 0) {
                         dw_log_dwstr_str("Warning: Dictionary element \"",
@@ -587,6 +595,7 @@ void dwm_dict_add(int num, dw_str *key, dw_str *value, int todo) {
                         /*dw_fatal(
                             "Dictionary elements must be defined only once");*/
                 }
+#endif /* TINY_BINARY */
                 key_d[num] = dwd_add(key_d[num],key,value);
                 return;
         }
