@@ -1,4 +1,4 @@
-/* Copyright (c) 2007-2012 Sam Trenholme
+/* Copyright (c) 2007-2011 Sam Trenholme
  *
  * TERMS
  *
@@ -67,14 +67,13 @@
 #define DWM_N_truncation_hack 26
 #define DWM_N_reject_ptr 27
 #define DWM_N_min_ttl_incomplete_cname 28
-#define DWM_N_max_ttl 29
 
 /* Number of string parameters in the mararc file */
 #define KEY_S_COUNT 7
 /* Number of dictionary parameters in the mararc file */
 #define KEY_D_COUNT 2
 /* Number of numeric parameters in the mararc file */
-#define KEY_N_COUNT 30
+#define KEY_N_COUNT 29
 
 #ifndef MINGW
 /* Location of files we read when we run execfile("foo") */
@@ -148,7 +147,6 @@ char *key_n_names[KEY_N_COUNT + 1] = {
                          synthetic "not there" reply */
         "min_ttl_incomplete_cname", /* How long to store incomplete CNAME
                                      * records in the cache, in seconds */
-        "max_ttl", /* Maximum allowed TTL */
         0 };
 
 #endif /* MARARC_C */
