@@ -71,7 +71,6 @@ int32_t min_bind = 15000;
 int32_t num_ports = 4096;
 int32_t maradns_uid = 99;
 int32_t maradns_gid = 99;
-int32_t max_ttl = 86400;
 int num_retries = 5;
 dwd_dict *blacklist_dict = 0;
 
@@ -501,10 +500,6 @@ void process_numeric_mararc_params() {
         maradns_gid = get_key_n(DWM_N_maradns_gid,10,65535,99);
         resurrections = get_key_n(DWM_N_resurrections,0,1,1);
         num_retries = get_key_n(DWM_N_num_retries,0,32,5);
-        max_ttl = get_key_n(DWM_N_max_ttl,
-                300 /* 5 minutes */,
-                7776000 /* 90 days */,
-                86400 /* One day */);
 
         if((num_ports & (num_ports - 1)) != 0) {
                 dw_fatal("num_ports must be a power of 2");
