@@ -1,4 +1,4 @@
-/* Copyright (c) 2007-2011 Sam Trenholme and others
+/* Copyright (c) 2007-2012 Sam Trenholme and others
  *
  * TERMS
  *
@@ -364,6 +364,7 @@ int forward_local_udp_packet(SOCKET sock, int32_t local_id,
      int len, int tcp_num, dw_str *orig_query) {
         int32_t b = 0;
         int num_alloc = 0;
+        ip_addr_T null_addr = {0,{0,0},0,0};
 
         num_alloc = key_n[DWM_N_max_inflights];
         if(num_alloc < 1) {
@@ -394,7 +395,10 @@ int forward_local_udp_packet(SOCKET sock, int32_t local_id,
         }
 
         rem[b].local[rem[b].num_locals - 1] = malloc(sizeof(local_T));
-        rem[b].local[rem[b].num_locals - 1]->orig_query = 0;
+        if(rem[b].local[rem[b].num_locals - 1] != 0) {
+                rem[b].local[rem[b].num_locals - 1]->orig_query = 0;
+                rem[b].local[rem[b].num_locals - 1]->action = 0;
+        }
         if(rem[b].socket == INVALID_SOCKET ||
            rem[b].local[rem[b].num_locals - 1] == 0) {
                 reset_rem(b);
@@ -404,6 +408,8 @@ int forward_local_udp_packet(SOCKET sock, int32_t local_id,
         rem[b].local[rem[b].num_locals - 1]->tcp_num = tcp_num;
         if(from_ip != 0) {
                 rem[b].local[rem[b].num_locals - 1]->ip = *from_ip;
+        } else {
+                rem[b].local[rem[b].num_locals - 1]->ip = null_addr;
         }
         rem[b].local[rem[b].num_locals - 1]->port = from_port;
         rem[b].local[rem[b].num_locals - 1]->local_id = local_id;
@@ -710,9 +716,13 @@ void get_local_udp_packet(SOCKET sock) {
                 goto catch_get_local_udp_packet;
         }
         if(get_reply_from_cache(query, &client, sock, local_id, 0, -1,
-                        orig_query, &from_ip) == 1) {
+                        orig_query, &from_ip) == 1) { /* Is answer in cache */
                 goto catch_get_local_udp_packet; /* In cache; we're done */
         }
+        if(dwx_cname_in_cache(orig_query, query, &client, &from_ip, local_id,
+                        sock, from_port) == 1) { /* CNAME refer in cache? */
+                goto catch_get_local_udp_packet;
+        }
 
         /* Nothing in cache; lets try sending the packet upstream */
         try_forward_local_udp_packet(sock,local_id,&from_ip,from_port,
@@ -1019,6 +1029,9 @@ int send_reply_from_cache(unsigned char *a, ssize_t count, int b, int l) {
                 } else if(rem[b].local[l]->glueless_type == 2) { /* CNAME */
                         dwx_incomplete_cname_done(query, b, l);
                         ret = 4; /* End connection */
+                } else if(rem[b].local[l]->glueless_type == 3) {/* Saw CNAME */
+                        dwx_cached_cname_done(query, b, l, 0);
+                        ret = 4; /* End connection */
                 }
                 goto catch_send_reply_from_cache;
         } else if (rem[b].local[l]->ip.len == 4) {
@@ -1068,7 +1081,7 @@ int get_rem_udp_packet_core(unsigned char *a, ssize_t count,
          * answers will be treated as if it has only one answer */
         if((a[2] & 0x02) != 0x00 && a[7] > 0 &&
                         key_n[DWM_N_truncation_hack] == 1) {
-                a[6] = 0;
+                a[6] = a[8] = a[9] = a[10] = a[11] = 0;
                 a[7] = 1;
                 /* Cut off answer after first reply */
                 for(z=12;z<count;z++) {
@@ -1145,7 +1158,7 @@ int get_rem_udp_packet_core(unsigned char *a, ssize_t count,
                         rem[b].local[l]->local_id,b,rem[b].is_upstream);
                 /* Give the UDP connection more time before timeout, so
                  * we can fully process the TCP connection */
-                rem[b].die = get_time() + ((int64_t)timeout_seconds << 10);
+                rem[b].die = get_time() + ((int64_t)timeout_seconds << 11);
                 return 2; /* Don't kill pending UDP connection */
         } else { /* Truncated over UDP; just given them a blank "truncated"
                   * reply */
